Driver

Trait Driver 

pub trait Driver: Send + Sync {
    // Required methods
    fn descriptor(&self) -> FormatDescriptor;
    fn open(
        &self,
        source: ByteSourceHandle,
        options: OpenOptions<'_>,
    ) -> Result<Box<dyn DataSource>>;
}
Format driver that opens one logical data source from a byte source.

Required Methods

fn descriptor(&self) -> FormatDescriptor

Return the descriptor handled by this driver.

fn open( &self, source: ByteSourceHandle, options: OpenOptions<'_>, ) -> Result<Box<dyn DataSource>>

Open a parsed data source from the provided byte source.

Implementors